;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "vterm-toggle" "20260420.1244"
  "Toggles between the vterm buffer and other buffers."
  '((emacs "25.1")
    (vterm "0.0.1"))
  :url "https://github.com/jixiuf/vterm-toggle"
  :commit "80989c6ca35416a5c85fa76277ef49a13c3eac11"
  :revdesc "80989c6ca354"
  :keywords '("vterm" "terminals")
  :authors '((nil . "jixiufjixiuf@qq.com"))
  :maintainers '((nil . "jixiufjixiuf@qq.com")))
